================================================
``psyclone.psyir.transformations.extract_trans``
================================================

.. automodule:: psyclone.psyir.transformations.extract_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.extract_trans
